@@ -45,6 +45,9 @@ import javax.xml.transform.stream.StreamResult;
 import org.apache.maven.model.Resource;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugin.MojoFailureException;
+import org.apache.maven.plugins.annotations.LifecyclePhase;
+import org.apache.maven.plugins.annotations.Mojo;
+import org.apache.maven.plugins.annotations.Parameter;
 import org.apache.maven.project.MavenProject;
 import org.codehaus.mojo.xml.transformer.NameValuePair;
 import org.codehaus.mojo.xml.transformer.TransformationSet;
@@ -53,34 +56,30 @@ import org.codehaus.plexus.util.FileUtils;
 import org.codehaus.plexus.util.IOUtil;
 import org.xml.sax.InputSource;
 
-
 /**
  * The TransformMojo is used for transforming a set of files using a common stylesheet.
- *
- * @goal transform
- * @phase generate-resources
  */
-public class TransformMojo extends AbstractXmlMojo
+@Mojo( defaultPhase = LifecyclePhase.GENERATE_RESOURCES, name = "transform", threadSafe = true )
+public class TransformMojo
+    extends AbstractXmlMojo
 {
     /**
-     * Specifies one or more sets of files, which are being
-     * transformed.
-     * @parameter
+     * Specifies one or more sets of files, which are being transformed.
      */
+    @Parameter
     private TransformationSet[] transformationSets;
 
     /**
      * Whether creating the transformed files should be forced.
-     * @parameter expression="${xml.forceCreation}" default-value="false"
      */
+    @Parameter( property = "xml.forceCreation", defaultValue = "false" )
     private boolean forceCreation;
 
     /**
-     * Transformer factory use. By default, the systems default transformer
-     * factory is used.
-     * <b>If you use this feature you must use at least jdk 1.6</b>
-     * @parameter expression="${xml.transformerFactory}"
+     * Transformer factory use. By default, the systems default transformer factory is used. <b>If you use this feature
+     * you must use at least jdk 1.6</b>
      */
+    @Parameter( property = "xml.transformerFactory" )
     private String transformerFactory;
 
     private void setFeature( TransformerFactory pTransformerFactory, String name, Boolean value )
@@ -90,7 +89,7 @@ public class TransformMojo extends AbstractXmlMojo
         Method m;
         try
         {
-            m = pTransformerFactory.getClass().getMethod( "setFeature", new Class[]{ String.class, boolean.class } );
+            m = pTransformerFactory.getClass().getMethod( "setFeature", new Class[] { String.class, boolean.class } );
         }
         catch ( NoSuchMethodException e )
         {
@@ -105,7 +104,7 @@ public class TransformMojo extends AbstractXmlMojo
         {
             try
             {
-                m.invoke( pTransformerFactory, new Object[]{ name, value } );
+                m.invoke( pTransformerFactory, new Object[] { name, value } );
             }
             catch ( IllegalAccessException e )
             {
@@ -131,11 +130,11 @@ public class TransformMojo extends AbstractXmlMojo
         NameValuePair[] features = transformationSet.getFeatures();
         if ( features != null )
         {
-            for ( int i = 0;  i < features.length;  i++ )
+            for ( int i = 0; i < features.length; i++ )
             {
                 final NameValuePair feature = features[i];
                 final String name = feature.getName();
-                if ( name == null  ||  name.length() == 0 )
+                if ( name == null || name.length() == 0 )
                 {
                     throw new MojoFailureException( "A features name is missing or empty." );
                 }
@@ -150,11 +149,11 @@ public class TransformMojo extends AbstractXmlMojo
         NameValuePair[] attributes = transformationSet.getAttributes();
         if ( attributes != null )
         {
-            for ( int i = 0;  i < attributes.length;  i++ )
+            for ( int i = 0; i < attributes.length; i++ )
             {
                 final NameValuePair attribute = attributes[i];
                 final String name = attribute.getName();
-                if ( name == null  ||  name.length() == 0 )
+                if ( name == null || name.length() == 0 )
                 {
                     throw new MojoFailureException( "An attributes name is missing or empty." );
                 }
@@ -175,17 +174,18 @@ public class TransformMojo extends AbstractXmlMojo
             throw new MojoExecutionException( "Failed to parse stylesheet " + stylesheet + ": " + e.getMessage(), e );
         }
     }
-    
+
     /**
      * Creates a new instance of {@link TransformerFactory}.
      */
-    private TransformerFactory getTransformerFactory( ) throws MojoFailureException, MojoExecutionException
+    private TransformerFactory getTransformerFactory()
+        throws MojoFailureException, MojoExecutionException
     {
         if ( transformerFactory == null )
         {
             return TransformerFactory.newInstance();
         }
-        
+
         try
         {
             return newTransformerFactory( transformerFactory, Thread.currentThread().getContextClassLoader() );
@@ -203,7 +203,7 @@ public class TransformMojo extends AbstractXmlMojo
             throw new MojoExecutionException( "Cannot instantiate transformer factory", exception );
         }
     }
-    
+
     // public for use by unit test
     public static TransformerFactory newTransformerFactory( String factoryClassName, ClassLoader classLoader )
         throws NoSuchMethodException, IllegalAccessException, InvocationTargetException
@@ -211,11 +211,11 @@ public class TransformMojo extends AbstractXmlMojo
         // use reflection to avoid JAXP 1.4 (and hence JDK6) requirement
 
         Class[] methodTypes = new Class[] { String.class, ClassLoader.class };
-        
+
         Method method = TransformerFactory.class.getDeclaredMethod( "newInstance", methodTypes );
-        
+
         Object[] methodArgs = new Object[] { factoryClassName, classLoader };
-        
+
         return (TransformerFactory) method.invoke( null, methodArgs );
     }
 
@@ -240,9 +240,9 @@ public class TransformMojo extends AbstractXmlMojo
     private void addToClasspath( File pOutputDir )
     {
         MavenProject project = getProject();
-        for ( Iterator iter = project.getResources().iterator(); iter.hasNext(); )
+        for ( Iterator<Resource> iter = project.getResources().iterator(); iter.hasNext(); )
         {
-            Resource resource = (Resource) iter.next();
+            Resource resource = iter.next();
             if ( resource.getDirectory().equals( pOutputDir ) )
             {
                 return;
@@ -283,13 +283,11 @@ public class TransformMojo extends AbstractXmlMojo
     }
 
     /**
-     * 
      * @param files the fileNames or URLs to scan their lastModified timestamp.
-     * @param oldest if true, returns the latest modificationDate of all files,
-     *      otherwise returns the earliest.
+     * @param oldest if true, returns the latest modificationDate of all files, otherwise returns the earliest.
      * @return the older or younger last modification timestamp of all files.
      */
-    protected long findLastModified( List/*<Object>*/files, boolean oldest )
+    protected long findLastModified( List/* <Object> */ files, boolean oldest )
     {
         long timeStamp = ( oldest ? Long.MIN_VALUE : Long.MAX_VALUE );
         for ( Iterator it = files.iterator(); it.hasNext(); )
@@ -305,7 +303,7 @@ public class TransformMojo extends AbstractXmlMojo
                 }
                 else // either URL or filePath
                 {
-                    
+
                     String sdep = no.toString();
 
                     try
@@ -327,8 +325,8 @@ public class TransformMojo extends AbstractXmlMojo
                     {
                         fileModifTime = ( oldest ? Long.MIN_VALUE : Long.MAX_VALUE );
                         getLog().warn( "Skipping URL '" + no
-                                           + "' from up-to-date check due to error while opening connection: "
-                                           + getAllExMsgs( ex, true ) );
+                            + "' from up-to-date check due to error while opening connection: "
+                            + getAllExMsgs( ex, true ) );
                     }
 
                 }
@@ -345,7 +343,7 @@ public class TransformMojo extends AbstractXmlMojo
         if ( timeStamp == Long.MIN_VALUE )
         {
             // no older file found
-            return Long.MAX_VALUE; // assume re-execution required. 
+            return Long.MAX_VALUE; // assume re-execution required.
         }
         else if ( timeStamp == Long.MAX_VALUE )
         {
@@ -357,9 +355,8 @@ public class TransformMojo extends AbstractXmlMojo
     }
 
     /**
-     * @return true to indicate results are up-to-date, that is, when the latest 
-     *          from input files is earlier than the younger from the output 
-     *          files (meaning no re-execution required).
+     * @return true to indicate results are up-to-date, that is, when the latest from input files is earlier than the
+     *         younger from the output files (meaning no re-execution required).
      */
     protected boolean isUpdToDate( List dependsFiles, List producesFiles )
     {
@@ -367,12 +364,11 @@ public class TransformMojo extends AbstractXmlMojo
         long inputTimeStamp = findLastModified( dependsFiles, true );
 
         // The younger of all destination files.
-        long destTimeStamp = producesFiles == null
-            ? Long.MIN_VALUE : findLastModified( producesFiles, false ); 
-    
-            getLog().debug( "Depends timeStamp: " + inputTimeStamp + ", produces timestamp: " + destTimeStamp );
+        long destTimeStamp = producesFiles == null ? Long.MIN_VALUE : findLastModified( producesFiles, false );
 
-        return inputTimeStamp < destTimeStamp; 
+        getLog().debug( "Depends timeStamp: " + inputTimeStamp + ", produces timestamp: " + destTimeStamp );
+
+        return inputTimeStamp < destTimeStamp;
     }
 
     private void transform( Transformer pTransformer, File input, File output, Resolver pResolver )
@@ -384,28 +380,30 @@ public class TransformMojo extends AbstractXmlMojo
         FileOutputStream fos = null;
         try
         {
-        	final boolean transformInPlace = output.equals( input );
-        	File tmpOutput = null;
-        	if ( transformInPlace ) {
-        		tmpOutput = File.createTempFile( "xml-maven-plugin", "xml" );
-        		tmpOutput.deleteOnExit();
+            final boolean transformInPlace = output.equals( input );
+            File tmpOutput = null;
+            if ( transformInPlace )
+            {
+                tmpOutput = File.createTempFile( "xml-maven-plugin", "xml" );
+                tmpOutput.deleteOnExit();
                 fos = new FileOutputStream( tmpOutput );
-        	}
-        	else
-        	{
-        		fos = new FileOutputStream( output );
-        	}
+            }
+            else
+            {
+                fos = new FileOutputStream( output );
+            }
 
-        	final String parentFile = input.getParent() == null
-                ? null : input.getParentFile().toURI().toURL().toExternalForm();
-            pTransformer.transform( pResolver.resolve( input.toURI().toURL().toExternalForm(),
-                                                       parentFile ), new StreamResult( fos ) );
+            final String parentFile =
+                input.getParent() == null ? null : input.getParentFile().toURI().toURL().toExternalForm();
+            pTransformer.transform( pResolver.resolve( input.toURI().toURL().toExternalForm(), parentFile ),
+                                    new StreamResult( fos ) );
             fos.close();
             fos = null;
-            if ( transformInPlace ) {
-            	FileUtils.copyFile( tmpOutput, output );
-            	/* tmpOutput is a temporary file */
-            	tmpOutput.delete();
+            if ( transformInPlace )
+            {
+                FileUtils.copyFile( tmpOutput, output );
+                /* tmpOutput is a temporary file */
+                tmpOutput.delete();
             }
         }
         catch ( IOException e )
@@ -439,7 +437,7 @@ public class TransformMojo extends AbstractXmlMojo
         String name = pName;
         if ( pFileMappers != null )
         {
-            for ( int i = 0;  i < pFileMappers.length;  i++ )
+            for ( int i = 0; i < pFileMappers.length; i++ )
             {
                 name = pFileMappers[i].getMappedFileName( name );
             }
@@ -450,10 +448,9 @@ public class TransformMojo extends AbstractXmlMojo
     private void transform( Resolver pResolver, TransformationSet pTransformationSet )
         throws MojoExecutionException, MojoFailureException
     {
-        String[] fileNames = getFileNames( pTransformationSet.getDir(),
-                                           pTransformationSet.getIncludes(),
-                                           getExcludes( pTransformationSet.getExcludes(),
-                                                        pTransformationSet.isSkipDefaultExcludes() ) );
+        String[] fileNames =
+            getFileNames( pTransformationSet.getDir(), pTransformationSet.getIncludes(),
+                          getExcludes( pTransformationSet.getExcludes(), pTransformationSet.isSkipDefaultExcludes() ) );
         if ( fileNames == null || fileNames.length == 0 )
         {
             getLog().warn( "No files found for transformation by stylesheet " + pTransformationSet.getStylesheet() );
@@ -472,29 +469,29 @@ public class TransformMojo extends AbstractXmlMojo
         InputStream stream = null;
         try
         {
-        	stream = stylesheetUrl.openStream();
-        	InputSource isource = new InputSource( stream );
-        	isource.setSystemId( stylesheetUrl.toExternalForm() );
-        	template = getTemplate( pResolver, new SAXSource( isource ), pTransformationSet );
-        	stream.close();
-        	stream = null;
+            stream = stylesheetUrl.openStream();
+            InputSource isource = new InputSource( stream );
+            isource.setSystemId( stylesheetUrl.toExternalForm() );
+            template = getTemplate( pResolver, new SAXSource( isource ), pTransformationSet );
+            stream.close();
+            stream = null;
         }
         catch ( IOException e )
         {
-        	throw new MojoExecutionException( e.getMessage(), e );
+            throw new MojoExecutionException( e.getMessage(), e );
         }
         finally
         {
-        	IOUtil.close( stream );
+            IOUtil.close( stream );
         }
-        
+
         int filesTransformed = 0;
         File inputDir = getDir( pTransformationSet.getDir() );
         File outputDir = getOutputDir( pTransformationSet.getOutputDir() );
         for ( int i = 0; i < fileNames.length; i++ )
         {
             final Transformer t;
-            
+
             File input = getFile( inputDir, fileNames[i] );
             File output = getOutputFile( outputDir, fileNames[i], pTransformationSet.getFileMappers() );
 
@@ -509,7 +506,7 @@ public class TransformMojo extends AbstractXmlMojo
                 dependsFiles.add( getProject().getFile() );
                 if ( "file".equals( stylesheetUrl.getProtocol() ) )
                 {
-                	dependsFiles.add( new File( stylesheetUrl.getFile() ) );
+                    dependsFiles.add( new File( stylesheetUrl.getFile() ) );
                 }
                 List catalogFiles = new ArrayList();
                 List catalogUrls = new ArrayList();
@@ -517,16 +514,16 @@ public class TransformMojo extends AbstractXmlMojo
                 dependsFiles.addAll( catalogFiles );
                 dependsFiles.add( input );
                 File[] files = asFiles( getBasedir(), pTransformationSet.getOtherDepends() );
-                for ( int j = 0;  j < files.length;  j++ )
+                for ( int j = 0; j < files.length; j++ )
                 {
                     dependsFiles.add( files[j] );
                 }
 
                 producesFiles.add( output );
-                
+
                 needsTransform = !isUpdToDate( dependsFiles, producesFiles );
             }
-            
+
             if ( !needsTransform )
             {
                 getLog().debug( "Skipping XSL transformation.  File " + fileNames[i] + " is up-to-date." );
@@ -534,7 +531,7 @@ public class TransformMojo extends AbstractXmlMojo
             else
             {
                 filesTransformed++;
-                
+
                 // Perform transformation.
                 try
                 {
@@ -544,15 +541,15 @@ public class TransformMojo extends AbstractXmlMojo
                     NameValuePair[] parameters = pTransformationSet.getParameters();
                     if ( parameters != null )
                     {
-                        for ( int j = 0;  j < parameters.length;  j++  )
+                        for ( int j = 0; j < parameters.length; j++ )
                         {
                             NameValuePair key = parameters[j];
                             t.setParameter( key.getName(), key.getValue() );
                         }
                     }
-                    
+
                     transform( t, input, output, pResolver );
-                    
+
                 }
                 catch ( TransformerConfigurationException e )
                 {
@@ -565,7 +562,7 @@ public class TransformMojo extends AbstractXmlMojo
         {
             getLog().info( "Transformed " + filesTransformed + " file(s)." );
         }
-        
+
         if ( pTransformationSet.isAddedToClasspath() )
         {
             addToClasspath( pTransformationSet.getOutputDir() );
@@ -579,10 +576,10 @@ public class TransformMojo extends AbstractXmlMojo
         NameValuePair[] properties = pTransformationSet.getOutputProperties();
         if ( properties != null )
         {
-            for ( int i = 0;  i < properties.length;  i++ )
+            for ( int i = 0; i < properties.length; i++ )
             {
                 final String name = properties[i].getName();
-                if ( name == null  ||  "".equals( name ) )
+                if ( name == null || "".equals( name ) )
                 {
                     throw new MojoFailureException( "Missing or empty output property name" );
                 }
@@ -597,10 +594,8 @@ public class TransformMojo extends AbstractXmlMojo
                 }
                 catch ( IllegalArgumentException e )
                 {
-                    throw new MojoExecutionException( "Unsupported property name or value: "
-                                                      + name + " => "
-                                                      + value
-                                                      + e.getMessage(), e );
+                    throw new MojoExecutionException( "Unsupported property name or value: " + name + " => " + value
+                        + e.getMessage(), e );
                 }
             }
         }
@@ -613,6 +608,11 @@ public class TransformMojo extends AbstractXmlMojo
     public void execute()
         throws MojoExecutionException, MojoFailureException
     {
+        if ( isSkipping() )
+        {
+            getLog().debug( "Skipping execution, as demanded by user." );
+            return;
+        }
         if ( transformationSets == null || transformationSets.length == 0 )
         {
             throw new MojoFailureException( "No TransformationSets configured." );
@@ -621,7 +621,7 @@ public class TransformMojo extends AbstractXmlMojo
         Object oldProxySettings = activateProxy();
         try
         {
-            Resolver resolver = getResolver( );
+            Resolver resolver = getResolver();
             for ( int i = 0; i < transformationSets.length; i++ )
             {
                 TransformationSet transformationSet = transformationSets[i];
